Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(677)

Unified Diff: runtime/vm/object.h

Issue 10832214: Move deopt reason into PcDescriptor so the EAX/RAX register is not destroyed. Some cleanups in PC d… (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/intermediate_language_x64.cc ('k') | runtime/vm/object.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/object.h
===================================================================
--- runtime/vm/object.h (revision 10420)
+++ runtime/vm/object.h (working copy)
@@ -2168,13 +2168,15 @@
// Describes the layout of PC descriptor data.
enum {
kPcEntry = 0, // PC value of the descriptor, unique.
- kKindEntry,
- kDeoptIdEntry, // Deopt id.
- kTokenPosEntry, // Token position in source of PC.
- kTryIndexEntry, // Try block index of PC.
+ kKindEntry = 1,
+ kDeoptIdEntry = 2, // Deopt id.
+ kTokenPosEntry = 3, // Token position in source.
+ kDeoptReasonEntry = 3, // DeoptReasonId.
+ kTryIndexEntry = 4, // Try block index.
+ kDeoptIndexEntry = 4, // Deoptimization array index.
// We would potentially be adding other objects here like
// pointer maps for optimized functions, local variables information etc.
- kNumberOfEntries
+ kNumberOfEntries = 5,
};
public:
@@ -2196,15 +2198,17 @@
intptr_t DeoptId(intptr_t index) const;
intptr_t TokenPos(intptr_t index) const;
intptr_t TryIndex(intptr_t index) const;
+ // Different encoding for kDeoptIndex.
// Index into the deopt-info array of Code object.
intptr_t DeoptIndex(intptr_t index) const;
+ intptr_t DeoptReason(intptr_t index) const;
void AddDescriptor(intptr_t index,
uword pc,
PcDescriptors::Kind kind,
intptr_t deopt_id,
- intptr_t token_pos,
- intptr_t try_index) const {
+ intptr_t token_pos, // Or deopt reason.
+ intptr_t try_index) const { // Or deopt index.
SetPC(index, pc);
SetKind(index, kind);
SetDeoptId(index, deopt_id);
« no previous file with comments | « runtime/vm/intermediate_language_x64.cc ('k') | runtime/vm/object.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698